@@ -1,7 +1,7 @@
 import snowflake.connector
 import settings
 import pickle
-import os 
+import os, sys 
 from snowflake.sqlalchemy import URL
 from sqlalchemy import create_engine
 import pandas.io.sql as pdsql
@@ -12,6 +12,9 @@ from os import path
 import numpy as np
 import pandas as pd
 from snowflake.connector.pandas_tools import pd_writer
+import pytz
+import hashlib
+import getpass
 
 def help():
     '''
@@ -65,11 +68,12 @@ def load_via_sql_snowflake(load_df, tbl_name, if_exists='replace', creds=None, t
     creds : if personal connection creds need to be passed in
     test_mode : default None, anything else will create a table called tbl_name + '_test'
     '''
-    print('loading tbl ' + tbl_name)
 
     if test_mode is not None:
         tbl_name += '_test'
 
+    print('loading tbl ' + tbl_name)
+
     if creds is None:
         creds=settings.SNOWFLAKE_FPA
 
@@ -127,20 +131,31 @@ def get_logger(filename):
     logger = logging.getLogger(__name__)
 
     '''
-
-    full_path = filename + '/logs'
-    if path.exists(full_path):
-        print('found logs file, will be creating new logger in there')
-    else:
-        os.mkdir(filename + '/logs')
-        print('You don\'t seem to have a logs file, what a shame. I\'ll go ahead and make one for you')
+    if sys.platform == "win32":
+        full_path = filename + r'\logs'
+        if path.exists(full_path):
+            print('found logs file, will be creating new logger in there')
+        else:
+            os.mkdir(filename + r'\logs')
+            print('You don\'t seem to have a logs file, what a shame. I\'ll go ahead and make one for you')
     
-    logging.basicConfig(filename=full_path + '/logger_' + str(dt.now()) + '.log',
-                            format='%(asctime)s :: %(name)s :: %(levelname)s :: %(message)s',
-                            filemode='a',
-                            datefmt='%H:%M:%S',
-                            level=logging.INFO)
-
+        logging.basicConfig(filename=full_path + r'\logger_' + dt.now().strftime('%Y-%m-%d %H.%M.%S') + '.log',
+            format='%(asctime)s :: %(name)s :: %(levelname)s :: %(message)s', 
+            filemode='a', 
+            datefmt='%H:%M:%S',
+            level=logging.INFO)
+    else:
+        full_path = filename + '/logs'
+        if path.exists(full_path):
+            print('found logs file, will be creating new logger in there')
+        else:
+            os.mkdir(filename + '/logs')
+            print('You don\'t seem to have a logs file, what a shame. I\'ll go ahead and make one for you')
+        logging.basicConfig(filename=full_path + '/logger_' + str(dt.now()) + '.log',
+            format='%(asctime)s :: %(name)s :: %(levelname)s :: %(message)s',
+            filemode='a',
+            datefmt='%H:%M:%S',
+            level=logging.INFO)
     return logging
 
 def get_snowflake_connection(usr, pwd, role, warehouse_name, db_name=None, schema=None):
@@ -253,32 +268,71 @@ def query_snowflake(query, q_type=None):
 
 
 
-def save_pickle(file_name, file_path_option=None):
+def save_pickle(df, file_name, folder_name=None, file_path_option=None):
     '''
-    Pickle function meant to save a file as a pickle using built-in Pickle library
+    Pickle function meant to save a file as a pickle using built-in Pickle library.
+    Will save file as 'file_name_yyyy_mm_dd.p' in specified file path.
+
+    vars
+    ------
+    df : pandas df to be pickled
+    file_name : name you want on the file
+    folder_name :  optional, folder name
+    file_path_option : optional, option for file path or custom path
 
     file_path_option are as follows:
-    'Tableau','Ad Hoc','Pickle', None
-    Note: None will default to cwd
+    - 'Tableau',
+    - 'Ad Hoc'
+    - 'Pickle'
+    - 'cwd'
+    Note: You can provide your own file path as well
     '''
 
     def file_path_loc(x):
         return {
-            None : os.path.dirname(os.path.realpath(__file__)),
+            'cwd' : os.path.dirname(os.path.realpath(__file__)),
             'Tableau' : settings.tableau_output_file_path,
-            'Ad Hoc' : settings.adhoc_output_file_path
-        }.get(x, os.path.dirname(os.path.realpath(__file__)))
-    
+            'Ad Hoc' : settings.adhoc_output_file_path,
+            'Pickle' : settings.pickle_file_path
+        }.get(x, x)
+
+    if folder_name is None:
+        folder_name = ''
+    else:
+        folder_name = folder_name + '/'
+
     fp = file_path_loc(file_path_option)
-    fp += 'pickle_data/unit_volume_asp_' + str(dt.today().date()).replace('-','_') + '.p'
+
+    if path.exists(fp + folder_name):
+        print('found path, will save pickle here')
+    else:
+        print('Unable to find path, attempting to create folder name to resolve...')
+        os.mkdir(fp + folder_name)
+
+    fp += folder_name + file_name + '_' + str(dt.today().date()).replace('-','_') + '.p'
     
-    pickle.dump(deal_data,open(fp, "wb"))
+    pickle.dump(df,open(fp, "wb"))
     print('Pickle Saved Successfully!')
 
-def load_pickle(file_name, load_date=None, file_path_option=None):
+def load_pickle(file_name, load_date=None, folder_name=None, file_path_option=None):
     '''
     Pickle function meant to load a saved pickle using built in Pickle library
 
+    vars
+    -----
+
+    file_name : name of file to be loaded from pickle
+    load_data : optional, date of pickle file, will default to current date
+    folder_name : optional, folder name to load from
+    file_path_option : optional, file path option or custom path
+
+    file_path_options
+    - Tableau
+    - Pickle
+    - Ad Hoc
+    - cwd
+    Note: you can provide your own file path as well
+
 
     '''
     try: 
@@ -290,20 +344,26 @@ def load_pickle(file_name, load_date=None, file_path_option=None):
         return {
             'Tableau' : settings.tableau_output_file_path,
             'Ad Hoc' : settings.adhoc_output_file_path,
-            'Pickle': settings.pickle_file_path
-        }.get(x, default_path)  
+            'Pickle': settings.pickle_file_path,
+            'cwd' : default_path
+        }.get(x, x)  
     
     if load_date is None:
         load_date = str(dt.today().date()).replace('-','_')
     
+    if folder_name is None:
+        folder_name = ''
+    else:
+        folder_name = folder_name + '/'
+
     fp = file_path_loc(file_path_option)
-    fp += file_name + '_' + str(load_date).replace('-','_') + '.p'
+    fp += folder_name + file_name + '_' + str(load_date).replace('-','_') + '.p'
     
     df = pickle.load( open (fp, "rb"))
     
     return df
 
-def start_batch(test_mode, table_name):
+def batch_start(test_mode, script_name):
     '''
     This function is built to natively load into the FBI's batch table. The batch table is meant to
     track progress of script runs, this functionality will exist until a better solution is implemented.
@@ -320,13 +380,14 @@ def start_batch(test_mode, table_name):
     This function will return a hash_id. You must store this hash_id as it will be how you will update the status of the batch
 
     '''
+    user_running = getpass.getuser()
     dt_now = pytz.timezone("US/Eastern").localize(dt.now())
     hash_id = hashlib.md5(str(dt.now()).encode('utf-8')).hexdigest()
 
     conn = get_snowflake_connection(**settings.SNOWFLAKE_FPA)
 
-    q = """INSERT INTO fpa_sandbox.batch_table (batch_status,start_time,batch_hash,test_mode,tbl_name) 
-                VALUES ('Running...','{}','{}','{}','{}');""".format(dt_now,hash_id,test_mode,table_name)
+    q = """INSERT INTO fpa_sandbox.batch_table (batch_status,start_time,batch_hash,test_mode,script_name, user_running) 
+                VALUES ('Running...','{}','{}','{}','{}','{}');""".format(dt_now,hash_id,test_mode,script_name,user_running)
 
     conn.cursor().execute(q)
     conn.close()
@@ -352,4 +413,4 @@ def batch_update(status, hash_id):
     conn.cursor().execute(q)
     conn.close()
 
-    
\ No newline at end of file
+    
